import * as React from 'react';
import {
  Table, Header, Container, Form, Checkbox, Button, Rating,
  List, Icon, Radio, CheckboxProps, Input, InputOnChangeData,
  Label, Segment,
} from 'semantic-ui-react';
import * as _ from 'lodash';
import MetaCrawler from '@overflow/meta/api/model/MetaCrawler';
import MetaCrawlerInputItem from '@overflow/meta/api/model/MetaCrawlerInputItem';


export interface StateProps {
  metaCrawler?: MetaCrawler;
  metaCrawlerInputItemList?: Array<MetaCrawlerInputItem>;
}

export interface DispatchProps {
}

export type Props = StateProps & DispatchProps;

export interface State {
  isVerifying: boolean;
  authJson: any;
  testMetaCrawlerInputItemList?: Array<MetaCrawlerInputItem>;
}

export class SensorConfigAuthCrawler extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);

    this.state = {
      isVerifying: false,
      authJson: {},
      testMetaCrawlerInputItemList: testMeta,
    };
  }


  public onChangeAuth = (key: string, data: string) => {
    let newJson: any = _.clone(this.state.authJson);
    newJson[key] = data;
    this.setState({ authJson: newJson });

    console.log(newJson);
  }

  public handleVerify(): void {
    this.setState({
      isVerifying: true,
    });

    // this.props.onVerifyCrawler(sd.infra.id, sd.crawler, sd.crawlerAuth);

    // let authCrawler: AuthCrawler = {
    //   crawler: { id: sd.crawler.id },
    //   target: { id: sd.infra.target.id },
    //   authJson: JSON.stringify(sd.crawlerAuth),
    // };

    // this.props.onRegistAuthCrawler(authCrawler);
  }


  public renderRow(item: MetaCrawlerInputItem, index: number): JSX.Element {
    let elem = new Array();
    if (item.inputType.name === 'TEXT_TYPE') {
      elem.push(<Input label={item.name} placeholder={item.defaultValue} key={index} onChange={
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.onChangeAuth(item.name, data.value);
        }} />);
    } else if (item.inputType.name === 'PASSWORD_TYPE') {
      elem.push(<Input label={item.name} type='password' placeholder={item.defaultValue} key={index} onChange={
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.onChangeAuth(item.name, data.value);
        }} />);
    } else if (item.inputType.name === 'SELECT_TYPE') {
      let itemValues = item.keyValue.split('|');
      let idx = 0;
      elem.push(<Label key={index} pointing='below'>{item.name}</Label>);

      if(this.state.authJson[item.name] === undefined) {
        //  this.onChangeAuth(item.name, item.defaultValue);
      }

      for (let itemValue of itemValues) {
           elem.push(
            <Form.Radio
              key={String(idx++) + '-' + String(index)}
              label={itemValue}
              name={'radioGroup' + String(item.id)}
              value={itemValue}
              checked={this.state.authJson[item.name] ? this.state.authJson[item.name] === itemValue : itemValue === item.defaultValue}
              defaultChecked={itemValue === item.defaultValue ? true : false}
              onChange={
                (event: React.FormEvent<HTMLInputElement>, data: CheckboxProps) => {
                  {/* this.onChangeAuth(item.name, itemValue); */}
                }
              }
            />);
        }
    }

    return (
      <Table.Row key={index}>
        <Table.Cell collapsing>{item.keyName}</Table.Cell>
        <Table.Cell >
          <Form.Group inline>{elem}</Form.Group>
        </Table.Cell>
      </Table.Row >
    );
  }

  public renderAuth(): JSX.Element[] {

    let mciil: Array<MetaCrawlerInputItem> = this.state.testMetaCrawlerInputItemList;

    if (mciil === undefined) {
      return null;
    }

    let elements: Array<JSX.Element> = new Array();
    let elem: JSX.Element;
    for (let index: number = 0; index < mciil.length; ++index) {
      elem = this.renderRow(mciil[index], index);
      elements.push(elem);
    }

    return elements;
  }


  public render(): JSX.Element {
    return (
      <Segment style={{ width: '350px' }}>
        <Table basic='very' celled >
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell colSpan='2'>{this.props.metaCrawler} 접속 정보</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.renderAuth()}
          </Table.Body>

          <Table.Footer>
            <Table.Row>
              <Table.HeaderCell colSpan='2'>
                {/*loading={this.state.isVerifying}*/}
                <Button primary floated={'right'} onClick={this.handleVerify.bind(this)} loading={this.state.isVerifying}>Verify</Button>
              </Table.HeaderCell>
            </Table.Row>
          </Table.Footer>
        </Table>
      </Segment>
    );
  }

}



const testMeta: any[] = [
  {
    'id' : 1,
    'create_date' : '2017-06-25T08:01:00Z',
    'default_value' : 'Loafle',
    'description' : 'Windows Account ID',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'ID',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 23,
    'type_id' : 1,
    'inputType' : {
      'id' : 1,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'TEXT',
      'name' : 'TEXT_TYPE',
    },
  },
  {
    'id' : 2,
    'create_date' : '2017-06-25T08:01:00Z',
    'default_value' : '',
    'description' : 'Windows Account PW',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'PassWord',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 23,
    'type_id' : 2,
    'inputType' : {
      'id' : 2,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'PASSWORD',
      'name' : 'PASSWORD_TYPE',
    },
  },
  {
    'id' : 3,
    'create_date' : '2017-06-25T08:01:00Z',
    'default_value' : 'public',
    'description' : 'SNMP V2 Community',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'Community',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 20,
    'type_id' : 1,
    'inputType' : {
      'id' : 1,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'TEXT',
      'name' : 'TEXT_TYPE',
    },
  },
  {
    'id' : 4,
    'create_date' : '2017-06-25T08:01:00Z',
    'default_value' : 'mysqldb',
    'description' : 'MYSQL DB Name',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'DB Name',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 11,
    'type_id' : 1,
    'inputType' : {
      'id' : 1,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'TEXT',
      'name' : 'TEXT_TYPE',
    },
  },
  {
    'id' : 5,
    'create_date' : '2017-06-25T08:01:00Z',
    'default_value' : 'Loafle',
    'description' : 'MYSQL Account ID',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'ID',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 11,
    'type_id' : 1,
    'inputType' : {
      'id' : 1,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'TEXT',
      'name' : 'TEXT_TYPE',
    },
  },
  {
    'id' : 6,
    'create_date' : '2017-06-25T08:01:00Z',
    'default_value' : '',
    'description' : 'MYSQL Account PW',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'PassWord',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 11,
    'type_id' : 2,
    'inputType' : {
      'id' : 2,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'PASSWORD',
      'name' : 'PASSWORD_TYPE',
    },
  },
  {
    'id' : 7,
    'create_date' : '2017-06-25T08:01:00Z',
    'default_value' : 'Loafle',
    'description' : 'JMX Account ID',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'ID',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 17,
    'type_id' : 1,
    'inputType' : {
      'id' : 1,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'TEXT',
      'name' : 'TEXT_TYPE',
    },
  },
  {
    'id' : 8,
    'create_date' : '2017-06-25T08:01:00Z',
    'default_value' : '',
    'description' : 'JMX Account PW',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'PassWord',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 17,
    'type_id' : 2,
    'inputType' : {
      'id' : 2,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'PASSWORD',
      'name' : 'PASSWORD_TYPE',
    },
  },
  {
    'id' : 9,
    'create_date' : '2017-09-11T09:41:00Z',
    'default_value' : 'MD5',
    'description' : 'SNMP V3 Auth Type',
    'keyName' : '',
    'keyValue' : 'MD5|SHA',
    'name' : 'AuthType',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 25,
    'type_id' : 5,
    'inputType' : {
      'id' : 5,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'SELECT',
      'name' : 'SELECT_TYPE',
    },
  },
  {
    'id' : 10,
    'create_date' : '2017-09-11T09:41:00Z',
    'default_value' : 'Loafle',
    'description' : 'SNMP V3 User ID',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'ID',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 25,
    'type_id' : 1,
    'inputType' : {
      'id' : 1,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'TEXT',
      'name' : 'TEXT_TYPE',
    },
  },
  {
    'id' : 11,
    'create_date' : '2017-09-11T09:41:00Z',
    'default_value' : '',
    'description' : 'SNMP V3 PassWord',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'PassWord',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 25,
    'type_id' : 2,
    'inputType' : {
      'id' : 2,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'PASSWORD',
      'name' : 'PASSWORD_TYPE',
    },
  },
  {
    'id' : 12,
    'create_date' : '2017-09-11T09:41:00Z',
    'default_value' : 'DES',
    'description' : 'SNMP V3 Encryption Type',
    'keyName' : '',
    'keyValue' : 'DES|AES',
    'name' : 'Encryption Type',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 25,
    'type_id' : 5,
    'inputType' : {
      'id' : 5,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'SELECT',
      'name' : 'SELECT_TYPE',
    },
  },
  {
    'id' : 13,
    'create_date' : '2017-09-11T09:41:00Z',
    'default_value' : 'Loafle',
    'description' : 'SNMP V3 Encryption Key',
    'keyName' : '',
    'keyValue' : '',
    'name' : 'Encryption Key',
    'pattern' : '',
    'required' : true,
    'crawler_id' : 25,
    'type_id' : 1,
    'inputType' : {
      'id' : 1,
      'create_date' : '2017-06-25T08:00:53Z',
      'description' : 'TEXT',
      'name' : 'TEXT_TYPE',
    },
  },
];
